@@ -214,6 +214,13 @@ extern WandExport MagickBooleanType
   MagickLevelImage(MagickWand *,const double,const double,const double),
   MagickLevelImageChannel(MagickWand *,const ChannelType,const double,
     const double,const double),
+  MagickLevelImageColors(MagickWand *,const PixelWand *,const PixelWand *,
+    const MagickBooleanType),
+  MagickLevelImageColorsChannel(MagickWand *,const ChannelType,
+    const PixelWand *,const PixelWand *,const MagickBooleanType),
+  MagickLevelizeImage(MagickWand *,const double,const double,const double),
+  MagickLevelizeImageChannel(MagickWand *,const ChannelType,const double,
+    const double,const double),
   MagickLinearStretchImage(MagickWand *,const double,const double),
   MagickLiquidRescaleImage(MagickWand *,const size_t,const size_t,const double,
     const double),
